from abrviz import Arbre, Noeud
import random


liste = list(range(20))
random.shuffle(liste)

a = Arbre()
a.fonction_ordre = lambda x, y: str(x.valeur) < str(y.valeur)

for e in liste:
    a.inserer(Noeud(e))

Arbre.sortie(a.racine, "exemple3_0", "png")

Arbre.options('node', {"style": "filled"})
Arbre.options('edge', {"arrowhead": "vee", "arrowsize": ".5"})
Arbre.sortie(a.racine, "exemple3_1", "png")

Arbre.options('graph', {"splines": "false"})
Arbre.sortie(a.racine, "exemple3_2", "png")



from setuptools import setup, find_packages

with open('README.md') as f:
    long_description = f.read()

setup(
    name='abrviz',
    version='0.2',
    description='Visualisation Arbre Binaire de Recherche',
    long_description_content_type='text/markdown',
    long_description=long_description,
    # url='https://twitter.com/david_cobac',
    url="https://github.com/cobacdavid/abrviz",
    author='David COBAC',
    author_email='david.cobac@gmail.com',
    license='CC-BY-NC-SA',
    keywords=['bst', 'abr', 'sort',
              'tri', 'tree', 'arbre'],
    packages=find_packages(),
    install_requires=["graphviz"],
    python_requires='>3.5'
)
